==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/duration/ChangeTupletoDurationAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.duration;

import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.component.UndoableComponentGeneric;
import org.herac.tuxguitar.song.models.Duration;
import org.herac.tuxguitar.song.models.Tupleto;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class ChangeTupletoDurationAction extends Action{
    public static final String NAME = "CHANGE_TUPLETO_DURATION";
    
    public ChangeTupletoDurationAction(TablatureEditor tablatureEditor) {
        super(NAME,true,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
    	UndoableComponentGeneric undoable = UndoableComponentGeneric.startUndo(); 
    	
        boolean isKeyEvent = false;
        if(e instanceof KeyEvent){
            isKeyEvent = true;
        }         
        if(!isKeyEvent){
            Tupleto tupleto = defaultTupleto();
            if(e.widget.getData() != null && e.widget.getData() instanceof Tupleto){
                tupleto = (Tupleto)e.widget.getData();
            }        
        
            if(getSelectedDuration().getTupleto().isEqual(tupleto)){
                setTupleto(noTupleto());              
            }else{
                setTupleto(tupleto);
            }
        }
        else{        
            if(getSelectedDuration().getTupleto().isEqual(Duration.NO_TUPLETO)){            
                setTupleto(defaultTupleto());
            }else{
                setTupleto(noTupleto());                    
            }
        }
        setDurations();     
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo()); 
        
        return true;
    }

    private Tupleto noTupleto(){
        return new Tupleto(1,1);
    }
    
    private Tupleto defaultTupleto(){
        return new Tupleto(3,2);
    }
    
    private void setTupleto(Tupleto tupleto){
        getSelectedDuration().getTupleto().setEnters(tupleto.getEnters());
        getSelectedDuration().getTupleto().setTimes(tupleto.getTimes());        
    }
    
    private void setDurations() {                
        Caret caret = getEditor().getTablature().getCaret();            
        caret.changeDuration((Duration)getSelectedDuration().clone());
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();        
    }    
    
    public Duration getSelectedDuration(){
        return getEditor().getTablature().getCaret().getDuration();
    }    

}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/actions/duration/ChangeTupletoDurationAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.duration;

import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.editors.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.measure.UndoableMeasureGeneric;
import org.herac.tuxguitar.song.models.Duration;
import org.herac.tuxguitar.song.models.Tupleto;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class ChangeTupletoDurationAction extends Action{
    public static final String NAME = "action.note.duration.change-tupleto";
    
    public ChangeTupletoDurationAction(TablatureEditor tablatureEditor) {
        super(NAME,true,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) {
        //comienza el undoable
    	UndoableMeasureGeneric undoable = UndoableMeasureGeneric.startUndo(); 
    	
        boolean isKeyEvent = false;
        if(e instanceof KeyEvent){
            isKeyEvent = true;
        }         
        if(!isKeyEvent){
            Tupleto tupleto = defaultTupleto();
            if(e.widget.getData() != null && e.widget.getData() instanceof Tupleto){
                tupleto = (Tupleto)e.widget.getData();
            }        
        
            if(getSelectedDuration().getTupleto().isEqual(tupleto)){
                setTupleto(noTupleto());              
            }else{
                setTupleto(tupleto);
            }
        }
        else{        
            if(getSelectedDuration().getTupleto().isEqual(Duration.NO_TUPLETO)){            
                setTupleto(defaultTupleto());
            }else{
                setTupleto(noTupleto());                    
            }
        }
        setDurations();     
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo()); 
        
        return true;
    }

    private Tupleto noTupleto(){
        return new Tupleto(1,1);
    }
    
    private Tupleto defaultTupleto(){
        return new Tupleto(3,2);
    }
    
    private void setTupleto(Tupleto tupleto){
        getSelectedDuration().getTupleto().setEnters(tupleto.getEnters());
        getSelectedDuration().getTupleto().setTimes(tupleto.getTimes());        
    }
    
    private void setDurations() {                
        Caret caret = getEditor().getTablature().getCaret();            
        caret.changeDuration((Duration)getSelectedDuration().clone());
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();        
    }    
    
    public Duration getSelectedDuration(){
        return getEditor().getTablature().getCaret().getDuration();
    }    

}
